@@ -49,7 +49,7 @@ class TestAsbool:
 
 
 class TestAverageFreq:
-    def setup(self):
+    def setup_method(self):
         self.small_data = np.arange(30, dtype=np.float32).reshape(5, 6, 1).repeat(2, axis=2)
         self.small_flags = np.zeros(self.small_data.shape, np.bool_)
         self.small_flags[3, :, 0] = 1
@@ -158,7 +158,7 @@ def test_time_median():
 class TestMedianAbs:
     """Test :func:`.twodflag._median_abs` and :func:`.twodflag._median_abs_axis0`."""
 
-    def setup(self):
+    def setup_method(self):
         self.data = np.array([[-2.0, -6.0, 4.5], [1.5, 3.3, 0.5]], np.float32)
         self.flags = np.array([[0, 0, 0], [0, 1, 0]], np.uint8)
 
@@ -185,7 +185,7 @@ class TestMedianAbs:
 class TestLinearlyInterpolateNans:
     """Tests for :func:`katsdpsigproc.rfi.twodflag._linearly_interpolate_nans`."""
 
-    def setup(self):
+    def setup_method(self):
         self.y = np.array([np.nan, np.nan, 4.0, np.nan, np.nan, 10.0, np.nan, -2.0, np.nan, np.nan])
         self.expected = np.array([4.0, 4.0, 4.0, 6.0, 8.0, 10.0, 4.0, -2.0, -2.0, -2.0])
 
@@ -289,7 +289,7 @@ class TestBoxGaussianFilter:
 
 
 class TestMaskedGaussianFilter:
-    def setup(self):
+    def setup_method(self):
         self.rs = np.random.RandomState(seed=1)
         shape = (77, 53)
         self.data = self.rs.uniform(size=shape).astype(np.float32)
@@ -337,7 +337,7 @@ class TestGetBackground2D:
     where large regions are flagged.
     """
 
-    def setup(self):
+    def setup_method(self):
         self.shape = (95, 86)
         self.data = np.ones(self.shape, np.float32) * 7.5
         self.flags = np.zeros(self.shape, np.uint8)
@@ -413,7 +413,7 @@ class TestGetBackground2D:
 
 
 class TestSumThreshold:
-    def setup(self):
+    def setup_method(self):
         self.small_data = np.arange(30, dtype=np.float32).reshape(5, 6)
         self.small_flags = np.zeros(self.small_data.shape, np.bool_)
         self.small_flags[3, :] = 1
@@ -489,7 +489,7 @@ class TestSumThreshold:
 class TestSumThresholdFlagger:
     """Tests for :class:`katsdpsigproc.rfi.twodflag.SumThresholdFlagger`."""
 
-    def setup(self):
+    def setup_method(self):
         self.flagger = twodflag.SumThresholdFlagger()
 
     def _make_background(self, shape, rs):
