@@ -470,8 +470,9 @@ class TestDimension:
 class TestIOSlot:
     """Tests for :class:`katsdpsigproc.accel.IOSlot`."""
 
+    @pytest.mark.parametrize("bind", [True, False])
     @mock.patch('katsdpsigproc.accel.DeviceArray', spec=True)
-    def test_allocate(self, DeviceArray: mock.Mock) -> None:
+    def test_allocate(self, DeviceArray: mock.Mock, bind: bool) -> None:
         """IOSlot.allocate must correctly allocate a buffer."""
         dims = (
             accel.Dimension(50, min_padded_size=60, alignment=8),
@@ -490,15 +491,33 @@ class TestIOSlot:
         DeviceArray.return_value = ary
         # Run the system under test
         slot = accel.IOSlot(dims, dtype)
-        ret = slot.allocate(accel.DeviceAllocator(mock.sentinel.context))
+        ret = slot.allocate(accel.DeviceAllocator(mock.sentinel.context), bind=bind)
         # Validation
         assert ret == ary
-        assert slot.buffer == ary
+        if bind:
+            assert slot.buffer == ary
+        else:
+            assert slot.buffer is None
         DeviceArray.assert_called_once_with(
             mock.sentinel.context, shape, dtype, padded_shape, None)
         # Check that the inner dimension had a type hint set
         assert dims[1].alignment_hint == accel.Dimension.ALIGN_BYTES
 
+    @mock.patch('katsdpsigproc.accel.HostArray', spec=True)
+    def test_allocate_host(self, HostArray: mock.Mock) -> None:
+        dims = (
+            accel.Dimension(50, min_padded_size=60, alignment=8),
+            accel.Dimension(30, min_padded_size=50, alignment=4)
+        )
+        shape = (50, 30)
+        padded_shape = (64, 52)
+        dtype = np.int16
+        slot = accel.IOSlot(dims, dtype)
+        HostArray.return_value = mock.sentinel.host_array
+        ret = slot.allocate_host(mock.sentinel.context)
+        assert ret is mock.sentinel.host_array
+        HostArray.assert_called_with(shape, dtype, padded_shape, context=mock.sentinel.context)
+
     @mock.patch('katsdpsigproc.accel.DeviceArray', spec=True)
     def test_allocate_raw(self, DeviceArray: mock.Mock) -> None:
         """Test IOSlot.allocate with a raw parameter."""
@@ -592,7 +611,7 @@ class TestIOSlot:
 class TestCompoundIOSlot:
     """Tests for :class:`katsdpsigproc.accel.CompoundIOSlot`."""
 
-    def setup(self) -> None:
+    def setup_method(self) -> None:
         self.dims1 = (
             accel.Dimension(13, min_padded_size=17, alignment=1),
             accel.Dimension(7, min_padded_size=8, alignment=8),
@@ -674,7 +693,7 @@ class TestCompoundIOSlot:
 class TestAliasIOSlot:
     """Tests for :class:`katsdpsigproc.accel.AliasIOSlot`."""
 
-    def setup(self) -> None:
+    def setup_method(self) -> None:
         self.slot1 = accel.IOSlot((3, 7), np.float32)
         self.slot2 = accel.IOSlot((5, 3), np.complex64)
 
@@ -697,6 +716,14 @@ class TestAliasIOSlot:
         assert self.slot1.buffer is not None
         assert self.slot2.buffer is not None
 
+    @mock.patch('katsdpsigproc.accel.HostArray', spec=True)
+    def test_allocate_host(self, HostArray: mock.Mock) -> None:
+        HostArray.return_value = mock.sentinel.host_array
+        slot = accel.AliasIOSlot([self.slot1, self.slot2])
+        ret = slot.allocate_host(mock.sentinel.context)
+        assert ret is mock.sentinel.host_array
+        HostArray.assert_called_with((120,), np.uint8, context=mock.sentinel.context)
+
 
 class TestVisualizeOperation:
     """Tests for :class:`katsdpsigproc.accel.visualize_operation`.
@@ -709,10 +736,10 @@ class TestVisualizeOperation:
         def _run(self) -> None:
             pass
 
-    def setup(self) -> None:
+    def setup_method(self) -> None:
         self.tmpdir = tempfile.mkdtemp()
 
-    def teardown(self) -> None:
+    def teardown_method(self) -> None:
         shutil.rmtree(self.tmpdir)
 
     def test(self, context: AbstractContext, command_queue: AbstractCommandQueue) -> None:
